@@ -1,6 +1,6 @@
 import typing
 
-import pkg_resources
+import importlib.util
 
 from .order import Order
 
@@ -15,18 +15,19 @@ def choice_in_order(
     :param module_names: list of module names
     :param order: order from worst to best to be installed
     :param do_import: should module be imported
-    :param default: default module name
+    :param default: default module name [deprecated]
     :return: module if do_import else module_name
     """
     default = default or module_names[0]
     installed = [
-        pkg.key for pkg in pkg_resources.working_set if pkg.key in module_names
+        module_name
+        for module_name in module_names
+        if importlib.util.find_spec(module_name) is not None
     ]
-    if not installed and default is None:
+    if not installed:
         raise ModuleNotFoundError(
-            "No required module variation was found. List: {}".format(
-                ", ".join(module_names)
-            )
+            "No proper module was installed. "
+            "List: {}".format(", ".join(module_names))
         )
 
     ordered_module_name = installed[order.value] if installed else default
